Welcome to ClientVPS Mirrors

Help for package AurieLSHGaussian
Type: Package
Title: Creates a Neighbourhood Using Locality Sensitive Hashing for Gaussian Projections
Version: 0.2.0
Author: Aritra Banerjee
Maintainer: Aritra Banerjee <aritra306@gmail.com>
Description: Uses locality sensitive hashing and creates a neighbourhood graph for a data set and calculates the adjusted rank index value for the same. It uses Gaussian random planes to decide the nature of a given point. Datar, Mayur, Nicole Immorlica, Piotr Indyk, and Vahab S. Mirrokni(2004) <doi:10.1145/997817.997857>.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: igraph, stringdist, reshape2, lsa
Imports: stats, flexclust
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2017-09-15 09:24:09 UTC; User
Repository: CRAN
Date/Publication: 2017-09-15 10:11:27 UTC

Creates a Neighbourhood Using Locality Sensitive Hashing for Gaussian Projections

Description

This package uses Locality Sensitive Hashing and creates a Neighbourhood Graph for a datset and calculates the ARI value for the same. It uses Gaussian Random planes to decide the nature of a given point.

Usage

LSH_Gaussian(mydata, result9)

Arguments

mydata

A data frame consisting of the data set without the class column

result9

A column which consists of the class column

Examples

LSH_Gaussian(iris[,-5],iris$Species)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.